import os
from datetime import date
from pathlib import Path
import webbrowser
import platform

import click

from fpdf import FPDF
import imagesize

from .cover_page_ams import create_cover_page
from .cover_page_project import create_project_cover
from .directory import get_images
from .mv import create_mv_folder
from .functions import get_client_and_project, get_date, get_project_number

font_path = "9999_BID_AMS/AMS-VFB_Fonts"

logo_path = "9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB.png"
logo_path_cover_page = "9999_BID_AMS/AMS_Logo's/RGB/Animotions_Logo_02_RGB_TextOnly.png"
proj_dir_windows = "X:/"
proj_dir_macos = "/Volumes/ams-fileserver/"

dir = Path(proj_dir_windows) if platform.system(
) == "Windows" else Path(proj_dir_macos)


frame_width = 200
frame_height = 170


def get_cwd():
    cwd = os.getcwd()
    if cwd[0] != 'X' and platform.system() == "Windows":
        click.secho("Please run the tool in the X:/ drive")
        return None

    if platform.system() != "Windows" and "ams-fileserver" not in cwd:
        click.secho("Try running the briefing tool inside X")
        return None

    if len(cwd) == 3:
        click.secho('Please run tool inside a project folder')
        return None

    return cwd


def main():
    logo = dir.joinpath(logo_path)
    cover_logo = dir.joinpath(logo_path_cover_page)
    font_dir = dir.joinpath(font_path)
    print(font_dir)
    click.echo(f"🥰 Let's create a briefing {os.getlogin()}!")
    pdf = FPDF(orientation='L', format='A4')
    pdf.set_author('Animotions')
    pdf.set_creator(os.getlogin())
    montserrat = font_dir.joinpath("Montserrat-ExtraBold.ttf")
    nexa = font_dir.joinpath("Nexa Regular Italic.ttf")

    pdf.add_font(family='montserrat',
                 fname=str(montserrat),
                 uni=True)

    pdf.add_font(family='nexa',
                 fname=str(nexa),
                 uni=True)

    project_path = Path(get_cwd())

    if project_path is None:
        return

    click.echo(f"🕵️‍♀️ We're running in {str(project_path)}")

    selection = get_images(project_path)

    project_name = input("🙏 Type in the project name: ")

    create_cover_page(pdf, cover_logo)
    create_project_cover(pdf, project_name)
    pdf.set_subject(project_name)
    pdf.set_title(f"Briefing - {project_name}")

    proj_number = get_project_number(project_path)

    if len(proj_number) != 4:
        click.secho('probber')

    files = [x for x in selection.iterdir() if x.is_file()
             and x.suffix == ".jpg"]
    for f in files:
        pdf.add_page()
        camname = f.stem.replace('_', ' ')
        pdf.set_font('Arial', 'B', size=18)
        pdf.cell(w=50, h=10, txt=project_name.upper(), align='R', ln=2)
        pdf.set_font('Arial', size=14)
        pdf.cell(w=50, h=10, txt=camname, align='R')
        pdf.image(str(logo),
                  x=9,
                  y=188,
                  w=65,
                  link="https://www.animotions.be")
        pdf.set_fill_color(200, 200, 200)
        pdf.rect(x=80, y=15, w=frame_width, h=frame_height, style='F')
        width, height = imagesize.get(str(f))

        if width > height:
            ratio = width/frame_width

            ratio_y = height/ratio

            pdf.image(str(f), x=80, y=15 +
                      (frame_height - ratio_y)/2, w=frame_width)

        if height > width:
            ratio = height/frame_height
            ratio_x = width/ratio
            pdf.image(str(f), x=80+(frame_width - ratio_x) /
                      2, y=15, h=frame_height)

    mv_dir = create_mv_folder(project_path, verbose=True)

    dest = mv_dir.joinpath(
        f'{get_date()}_{get_client_and_project(project_path)}_briefing.pdf')
    pdf.output(dest, 'F')
    webbrowser.open(dest)



import json
import os


def get_initials(employee: str) -> str:
    probe = os.path.join(os.path.dirname(__file__), "data", "employees.json")
    with open(probe) as json_file:
        data = json.load(json_file)
        return data[employee]


initials = get_initials('hanne')



import os
from pathlib import Path
from datetime import date

from .functions import get_client_and_project, get_date
from .employees import get_initials


def create_mv_folder(projectpath: str, verbose: bool):
    p = Path(projectpath)
    mv_probe = p.joinpath("MV")
    print(f"Probing {mv_probe}...") if verbose else None
    mv_subfolders = []
    for x in [x for x in Path(mv_probe).iterdir() if x.is_dir()]:
        if str(x.stem[0:2]).isdigit():
            mv_subfolders.append(str(x.stem[0:2]))

    newfolder = str(int(max(mv_subfolders))+1).zfill(2)
    projectcode = get_client_and_project(projectpath)

    foldername = f"{newfolder}_{get_date()}_{projectcode}_{get_initials(os.getlogin())}_Briefing"
    resultpath = mv_probe.joinpath(foldername)
    os.mkdir(resultpath)
    return resultpath



from datetime import date
from pathlib import Path


def get_project_number(projectpath: Path) -> str:
    return projectpath.stem[3:7]


def get_client_and_project(projectpath: Path) -> str:
    return projectpath.stem[8:15]


def get_date() -> str:
    return date.today().strftime('%Y%m%d')



from pathlib import Path
from pick import pick
import click
import os

filters = [
    "Mails&Vergaderingen",
    "ScriptGenerated",
    "MV",
    "Maps",
    "Proxy",
    "Xref",
    "Autoback",
    "AutoBackup",
    "Output",
    "Script",
    "renderpresets",
    "OnlineTool_Lab",
    "Documentatie"
]


def get_images(rootdir):
    #os.system('cls' if os.name == 'nt' else 'clear')

    options = []
    for path in Path(rootdir).rglob('**'):
        if path.is_dir() and not any([x in str(path) for x in filters]):
            files = [x for x in path.iterdir() if x.suffix == '.jpg']
            if len(files) > 0:
                options.append(path)
                # for f in files:
                #   print(f)
    option = pick(options, f"👋 {os.getlogin()}, pick a folder:", '=>')

    click.secho(f"🥳 You have selected {option[0]}!", fg='green')
    print(f"💁‍♀️ Here are the renders we found in {option[0]}:\n")

    for f in [x for x in Path(option[0]).iterdir() if x.is_file() and x.suffix == '.jpg']:
        print(f.name)

    while True:
        response = input(
            "\n🕵️‍♂️ Type 'y' or 'yes' to continue, 'n' or 'No' to start over...")
        if response == 'y' or response == 'Y' or response == 'yes':
            click.secho(f"👊 Ok, we're going with {option[0]}", fg='green')
            return option[0]
        elif response == 'n' or response == 'N' or response == 'no':
            click.secho("🙅‍♂️ Ok, we outta dis", fg='red')
            quit()
        else:
            print('no understandooooo')
            continue



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['ams_brief']

package_data = \
{'': ['*'], 'ams_brief': ['data/*']}

install_requires = \
['click>=8.1.3,<9.0.0',
 'fpdf>=1.7.2,<2.0.0',
 'imagesize>=1.3.0,<2.0.0',
 'pick>=1.2.0,<2.0.0']

entry_points = \
{'console_scripts': ['ams-brief = ams_brief.console:main']}

setup_kwargs = {
    'name': 'ams-brief',
    'version': '0.1.60',
    'description': '',
    'long_description': None,
    'author': 'Lucas',
    'author_email': 'lucas@animotions.be',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
